@@ -1,27 +1,31 @@
 library(foreign)
-sample100 <- read.spss("sample100.sav")
+sample100 <- read.spss("sample100.sav",FALSE)
 summary(sample100)
 str(sample100)
 sample100 <- data.frame(sample100)
 summary(sample100)
-sample100 <- read.spss("sample100.por")
+sample100 <- read.spss("sample100.por",FALSE)
 summary(sample100)
 str(sample100)
 sample100 <- data.frame(sample100)
 summary(sample100)
-pbc <- read.spss("pbc.sav")
+pbc <- read.spss("pbc.sav",FALSE)
 summary(pbc)
 str(pbc)
 pbc <- data.frame(pbc)
 summary(pbc)
-pbc <- read.spss("pbcold.sav")
+pbc <- read.spss("pbcold.sav",FALSE)
 summary(pbc)
 str(pbc)
 pbc <- data.frame(pbc)
 summary(pbc)
-pbc <- read.spss("pbc.por")
+pbc <- read.spss("pbc.por",FALSE)
 summary(pbc)
 str(pbc)
 pbc <- data.frame(pbc)
 summary(pbc)
+electric<-read.spss("electric.sav",TRUE,TRUE)
+summary(electric)
+electric<-read.spss("electric.por",TRUE,TRUE)
+summary(electric)
 q()
